@@ -18,11 +18,8 @@
 #include <bonobo/bonobo-ui-config-widget.h>
 #include <bonobo/bonobo-ui-sync-toolbar.h>
 #include <bonobo/bonobo-ui-toolbar.h>
-#include <libgnome/gnome-macros.h>
 
-GNOME_CLASS_BOILERPLATE (BonoboUIConfigWidget,
-			 bonobo_ui_config_widget,
-			 GtkVBox, GTK_TYPE_VBOX);
+G_DEFINE_TYPE (BonoboUIConfigWidget, bonobo_ui_config_widget, GTK_TYPE_VBOX)
 
 struct _BonoboUIConfigWidgetPrivate {
 	GtkTreeView  *list_view;
@@ -52,7 +49,7 @@ set_values (BonoboUIConfigWidget *config)
 	BonoboUINode *node;
 	gboolean hidden = FALSE;
 	gboolean tooltips = TRUE;
-	BonoboUIToolbarStyle style;
+	GtkToolbarStyle style;
 
 	g_return_if_fail (config->priv->cur_path != NULL);
 
@@ -75,24 +72,24 @@ set_values (BonoboUIConfigWidget *config)
 	style = bonobo_ui_sync_toolbar_get_look (config->engine, node);
 
 	switch (style) {
-	case BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY:
+	case GTK_TOOLBAR_ICONS:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->icon), TRUE);
 		break;
 
-	case BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT:
+	case GTK_TOOLBAR_BOTH:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->icon_and_text), TRUE);
 		break;
 
-	case BONOBO_UI_TOOLBAR_STYLE_TEXT_ONLY:
+	case GTK_TOOLBAR_TEXT:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->text), TRUE);
 		break;
 		
-	case BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT:
+	case GTK_TOOLBAR_BOTH_HORIZ: /* priority text */
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->priority_text), TRUE);
 		break;
 		
 	default:
-		g_warning ("Bogus style %d", style);
+		g_warning ("Bogus style %u", style);
 		break;
 	}
 	
@@ -359,7 +356,7 @@ widgets_init (BonoboUIConfigWidget *config,
 }
 
 static void
-bonobo_ui_config_widget_instance_init (BonoboUIConfigWidget *config)
+bonobo_ui_config_widget_init (BonoboUIConfigWidget *config)
 {
 	config->priv = g_new0 (BonoboUIConfigWidgetPrivate, 1);
 }
@@ -371,7 +368,7 @@ bonobo_ui_config_widget_finalize (GObject *object)
 
 	g_free (config->priv);
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (bonobo_ui_config_widget_parent_class)->finalize (object);
 }
 
 GtkWidget *
